Stan Math Library: stan::math::index_type< std::vector< T > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::index_type< std::vector< T > > Struct Template Reference

Template metaprogram class to compute the type of index for a standard vector. More...

`#include <index_type.hpp>`

## Public Types
typedef std::vector< T >::size_type | type
| Typedef for index of standard vectors. More...

## Detailed Description

### template<typename T>
struct stan::math::index_type< std::vector< T > >

Template metaprogram class to compute the type of index for a standard vector.

Template Parameters

  T | type of elements in standard vector.

Definition at line 18 of file index_type.hpp.

## Member Typedef Documentation

template<typename T >

typedef std::vector<T>::size_type stan::math::index_type< std::vector< T > >::type

Typedef for index of standard vectors.

Definition at line 22 of file index_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/arr/meta/index_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.